skbuild.platform_specifics package
==================================

.. automodule:: skbuild.platform_specifics
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

skbuild.platform_specifics.abstract module
------------------------------------------

.. automodule:: skbuild.platform_specifics.abstract
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.platform_specifics.bsd module
-------------------------------------

.. automodule:: skbuild.platform_specifics.bsd
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.platform_specifics.linux module
---------------------------------------

.. automodule:: skbuild.platform_specifics.linux
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.platform_specifics.osx module
-------------------------------------

.. automodule:: skbuild.platform_specifics.osx
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.platform_specifics.platform_factory module
--------------------------------------------------

.. automodule:: skbuild.platform_specifics.platform_factory
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.platform_specifics.unix module
--------------------------------------

.. automodule:: skbuild.platform_specifics.unix
    :members:
    :undoc-members:
    :show-inheritance:

skbuild.platform_specifics.windows module
-----------------------------------------

.. automodule:: skbuild.platform_specifics.windows
    :members:
    :undoc-members:
    :show-inheritance:


